@@ -1,4 +1,4 @@
-from jacdac.devtools import create_dev_tools_bus
+from ..bus import Bus
 from .server import AzureIotHubHealthServer
 from time import sleep
 import asyncio
@@ -7,7 +7,7 @@ import tracemalloc
 if __name__ == '__main__':
     async def main():
         tracemalloc.start()
-        bus = create_dev_tools_bus()
+        bus = Bus()
         hub_server = AzureIotHubHealthServer(bus)
         while True:
             sleep(1)
